<?php
/**
 * Flareblog functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Flareblog
 */

// Add more header layouts in customizer options.
if ( ! function_exists( 'blogvy_add_new_header_layouts' ) ) {
	function blogvy_add_new_header_layouts( $layouts ) {
		$layouts['header_style_3'] = array(
			'url'   => get_stylesheet_directory_uri() . '/assets/images/header3.png',
			'label' => esc_html__( 'Header Style 3', 'blogvy' ),
		);
		return $layouts;
	}
}
add_filter( 'blogvy_header_layouts', 'blogvy_add_new_header_layouts' );

if ( ! function_exists( 'blogvy_add_new_read_more_styles' ) ) :
	function blogvy_add_new_read_more_styles( $styles ) {
		return array_merge(
			$styles,
			array(
				'style_4' => __( 'Style 4', 'blogvy' ),
			)
		);
	}
endif;
add_filter( 'blogvy_read_more_styles', 'blogvy_add_new_read_more_styles' );

function flareblog_set_theme_mods() {

	$fresh_site_activate = get_option( 'flareblog_site_activate' );
	if ( (bool) $fresh_site_activate === false ) {
	
		$options = array(
			'header_style'                               => 'header_style_3',
			'global_border_radius_small'                 => 4,
			'global_border_radius_medium'                => 8,
			'global_border_radius_large'                 => 8,
			'enable_ticker_posts'                        => true,
			'ticker_label_style'                         => 'style_2',
			'ticker_label_bg_color'                      => '#f01111',
			'center_align_primary_nav'                   => false,
			'site_title_font_size_desktop'               => 18,
			'accent_color'                               => '#333333',
			'primary_color'                              => '#666666',
			'h1_color'                                   => '#000000',
			'h2_color'                                   => '#000000',
			'h3_color'                                   => '#000000',
			'h4_color'                                   => '#000000',
			'h5_color'                                   => '#000000',
			'h6_color'                                   => '#000000',
			'enable_top_bar'                             => true,
			'top_bar_theme'                              => 'dark',
			'top_bar_bg_color'                           => '#000000',
			'top_bar_date_color'                         => '#ffffff',
			'top_bar_nav_menu_color'                     => '#ffffff',
			'top_bar_nav_menu_hover_color'               => '#ffffff',
			'enable_topbar_social_nav'                   => false,
			'header_social_links_icons_color'            => '#ffffff',
			'header_social_links_icons_hover_color'      => '#ffffff',
			'header_social_links_label_color'            => '#ffffff',
			'enable_todays_time'                         => false,
			'enable_header_social_links_label'           => true,
			'primary_menu_bg_color'                      => '#fafafa',
			'show_menu_bar_social_nav'                   => false,
			'primary_font'                               => '"Jost", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif',
			'primary_font_weight'                        => 600,
			'secondary_font'                             => '"Inter", "100:200:300:regular:500:600:700:800:900", sans-serif',
			'secondary_font_weight'                      => 'normal',
			'primary_menu_font'                          => '"Jost", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif',
			'primary_menu_font_weight'                   => 500,
			'sub_menu_font'                              => '"Jost", "100:200:300:regular:500:600:700:800:900:100italic:200italic:300italic:italic:500italic:600italic:700italic:800italic:900italic", sans-serif',
			'sub_menu_font_weight'                       => 500,
			'global_show_title_line_hover'               => true,
			'archive_style'                              => 'archive_style_1',
			'pagination_type'                            => 'button_click_load',
			'center_aligned_pagination'                  => true,
			'archive_category_limit'                     => 1,
			'archive_category_style'                     => 'style_2',
			'archive_read_more_style'                    => 'style_2',
			'excerpt_read_more_icon'                     => 'send-fill',
			'excerpt_length'                             => 42,
			'enable_archive_author_image'                => true,
			'enable_single_author_image'                 => true,
			'author_info_title_style'                    => 'style_5',
			'author_info_title_align'                    => 'center',
			'author_info_box_style'                      => 'style_2',
			'related_posts_title_style'                  => 'style_5',
			'related_posts_title_align'                  => 'center',
			'single_comments_heading_style'              => 'style_5',
			'single_comments_heading_align'              => 'center',
			'author_posts_title_style'                   => 'style_5',
			'author_posts_title_align'                   => 'center',
			'footer_bg_color'                            => '#fafafa',
			'enable_border_above_footer'                 => false,
			'enable_border_above_sub_footer'             => false,
			'above_home_widgetarea_bg_color'             => '#feeaf0',
			'home_col_one_widgetarea_heading_style'      => 'style_8',
			'home_col_two_widgetarea_heading_style'      => 'style_5',
			'below_home_widgets_style'                   => 'style_4',
		);
	
		foreach ( $options as $key => $value ) {
			set_theme_mod( $key, $value );
		}
	
		update_option( 'flareblog_site_activate', true );
	}
}
add_action( 'after_switch_theme', 'flareblog_set_theme_mods' );